@@ -48,7 +48,9 @@
 #ifndef _WIN32
 # include <unistd.h>
 # include <sys/time.h>
-# include <sys/ucontext.h>
+# ifndef __ANDROID__
+#  include <sys/ucontext.h>
+# endif /* __ANDROID__ */
 # include <sys/mman.h>
 # ifndef CONFIG_TCC_STATIC
 #  include <dlfcn.h>
@@ -151,7 +153,7 @@
 # endif
 #endif
 
-#if defined TCC_IS_NATIVE && !defined CONFIG_TCCBOOT
+#if defined TCC_IS_NATIVE && !defined CONFIG_TCCBOOT && !defined __ANDROID__
 # define CONFIG_TCC_BACKTRACE
 #endif
 
